Index: lib/Bitcode/PNaCl/Writer/PNaClValueEnumerator.h |
diff --git a/lib/Bitcode/Writer/ValueEnumerator.h b/lib/Bitcode/PNaCl/Writer/PNaClValueEnumerator.h |
similarity index 88% |
copy from lib/Bitcode/Writer/ValueEnumerator.h |
copy to lib/Bitcode/PNaCl/Writer/PNaClValueEnumerator.h |
index 0af6164c944f83b0f20ea0e5595392b0cd9a8e6b..41af7a988c9a1cc64cdf7d2412178c5d99b97dee 100644 |
--- a/lib/Bitcode/Writer/ValueEnumerator.h |
+++ b/lib/Bitcode/PNaCl/Writer/PNaClValueEnumerator.h |
@@ -1,4 +1,4 @@ |
-//===-- Bitcode/Writer/ValueEnumerator.h - Number values --------*- C++ -*-===// |
+//===-- Bitcode/PNaCl/Writer/PNaClValueEnumerator.h - Number values --*- C++ -*-===// |
Karl
2013/04/24 18:25:59
Shortened line length.
|
// |
// The LLVM Compiler Infrastructure |
// |
@@ -11,8 +11,8 @@ |
// |
//===----------------------------------------------------------------------===// |
-#ifndef VALUE_ENUMERATOR_H |
-#define VALUE_ENUMERATOR_H |
+#ifndef PNACL_VALUE_ENUMERATOR_H |
+#define PNACL_VALUE_ENUMERATOR_H |
#include "llvm/ADT/DenseMap.h" |
#include "llvm/ADT/SmallVector.h" |
@@ -34,7 +34,7 @@ class ValueSymbolTable; |
class MDSymbolTable; |
class raw_ostream; |
-class ValueEnumerator { |
+class PNaClValueEnumerator { |
public: |
typedef std::vector<Type*> TypeList; |
@@ -83,10 +83,10 @@ private: |
unsigned FirstFuncConstantID; |
unsigned FirstInstID; |
- ValueEnumerator(const ValueEnumerator &) LLVM_DELETED_FUNCTION; |
- void operator=(const ValueEnumerator &) LLVM_DELETED_FUNCTION; |
+ PNaClValueEnumerator(const PNaClValueEnumerator &) LLVM_DELETED_FUNCTION; |
+ void operator=(const PNaClValueEnumerator &) LLVM_DELETED_FUNCTION; |
public: |
- ValueEnumerator(const Module *M); |
+ PNaClValueEnumerator(const Module *M); |
void dump() const; |
void print(raw_ostream &OS, const ValueMapType &Map, const char *Name) const; |
@@ -95,7 +95,7 @@ public: |
unsigned getTypeID(Type *T) const { |
TypeMapType::const_iterator I = TypeMap.find(T); |
- assert(I != TypeMap.end() && "Type not in ValueEnumerator!"); |
+ assert(I != TypeMap.end() && "Type not in PNaClValueEnumerator!"); |
return I->second-1; |
} |
@@ -105,14 +105,14 @@ public: |
unsigned getAttributeID(AttributeSet PAL) const { |
if (PAL.isEmpty()) return 0; // Null maps to zero. |
AttributeMapType::const_iterator I = AttributeMap.find(PAL); |
- assert(I != AttributeMap.end() && "Attribute not in ValueEnumerator!"); |
+ assert(I != AttributeMap.end() && "Attribute not in PNaClValueEnumerator!"); |
return I->second; |
} |
unsigned getAttributeGroupID(AttributeSet PAL) const { |
if (PAL.isEmpty()) return 0; // Null maps to zero. |
AttributeGroupMapType::const_iterator I = AttributeGroupMap.find(PAL); |
- assert(I != AttributeGroupMap.end() && "Attribute not in ValueEnumerator!"); |
+ assert(I != AttributeGroupMap.end() && "Attribute not in PNaClValueEnumerator!"); |
return I->second; |
} |
@@ -145,7 +145,7 @@ public: |
unsigned getGlobalBasicBlockID(const BasicBlock *BB) const; |
/// incorporateFunction/purgeFunction - If you'd like to deal with a function, |
/// use these two methods to get its data into the ValueEnumerator! |
/// |
void incorporateFunction(const Function &F); |
void purgeFunction(); |
@@ -145,7 +145,7 @@ public: |
unsigned getGlobalBasicBlockID(const BasicBlock *BB) const; |
/// incorporateFunction/purgeFunction - If you'd like to deal with a function, |
- /// use these two methods to get its data into the ValueEnumerator! |
+ /// use these two methods to get its data into the PNaClValueEnumerator! |
/// |
void incorporateFunction(const Function &F); |